@@ -4,10 +4,14 @@ __author__ = """ Jillian Rowe"""
 __email__ = "jillian@dabbleofdevops.com"
 __version__ = "0.1.0"
 
+import os
+
 from aws_pcluster_slurm_spawner.aws_pcluster_slurm_spawner import (
     PClusterSlurmSpawner,
 )
 
+pcluster_spawner_template_paths = os.path.join(os.path.dirname(__file__), "templates")
+
 from . import _version
 
 __version__ = _version.get_versions()["version"]
